==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CommandLine/ts/CommandLine_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+29"/>
        <location line="+48"/>
        <location filename="../CommandLine.ui" line="+14"/>
        <source>Command Line</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
Linha de Comando</translatorcomment>
        <translation>Linha de comando</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Coordenar inválido &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Unknown command &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Comando desconhecido &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="-19"/>
        <source>&amp;Command Line</source>
        <translation>Linha de &amp;comando</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;.</source>
        <translation type="obsolete">Coordenar inválido &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+159"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translation>Comando desconhecido ou coordenadas ou valor inválido: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translation>Números podem ser inseridos como: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translation>Coordenadas podem ser introduzidas como: &apos;%1&apos; (absoluto) ou &apos;%2&apos; (relativa) ou &apos;%3&apos; (polar) ou &apos;%4&apos; (relativa polar)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translation>Você pode alterar o formato número e coordenadas nas preferências do aplicativo.</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>Tentando aproveitar ou modificar as entidades em uma camada bloqueada.</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked or invisible layer.</source>
        <translation type="obsolete">Tentando aproveitar ou modificar as entidades em uma camada bloqueada.</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tentando aproveitar ou modificar as entidades em uma camada bloqueada.</translation>
    </message>
    <message>
        <location line="-273"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+169"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>Coordenar ou distância inválido &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Warning</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Aviso
Atenção
Aviso:</translatorcomment>
        <translation>Aviso</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Coordinate</source>
        <translatorcomment>--exact match--
--file: SnapCoordinate_pt.ts--
&amp;Coordenadas
Coordenadas
Salta a uma coordenada dada</translatorcomment>
        <translation>Coordenadas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
Linha de Comando</translatorcomment>
        <translation>Comando</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Comando:
Impossível executar o comando: %s</translatorcomment>
        <translation>Comando:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translatorcomment>--exact match--
--file: LibraryBrowser_pt.ts--
Desenho guardado: %1
Documento carregado: %1</translatorcomment>
        <translation>: </translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tamanho história:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translation>Mostrar uma caixa de diálogo para advertências</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translation>Mostrar uma caixa de diálogo para informações</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CommandLine/ts/CommandLine_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+30"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
Linha de Comando</translatorcomment>
        <translation>Linha de Comando</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Coordenar inválido &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Unknown command &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Comando desconhecido &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="-16"/>
        <source>&amp;Command Line</source>
        <translation>Linha de &amp;comando</translation>
    </message>
    <message>
        <source>Invalid coordinate &apos;%1&apos;.</source>
        <translation type="obsolete">Coordenar inválido &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+202"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translation>Comando desconhecido, ou coordenadas ou valor inválido: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translation>Números devem ser inseridos como: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translation>Coordenadas devem ser introduzidas como: &apos;%1&apos; (absoluta) ou &apos;%2&apos; (relativa) ou &apos;%3&apos; (polar) ou &apos;%4&apos; (polar relativa)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translation>Você pode modificar o número/formato das coordenadas nas preferências do aplicativo.</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>Falha na transação. Por favor verifique por autorreferências em Blocos ou camadas bloqueadas ou invisíveis nos Blocos.</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked or invisible layer.</source>
        <translation type="obsolete">Tentando aproveitar ou modificar as entidades em uma camada bloqueada.</translation>
    </message>
    <message>
        <source>Trying to draw on or modify entities on a locked layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tentando aproveitar ou modificar as entidades em uma camada bloqueada.</translation>
    </message>
    <message>
        <location line="-317"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Invalid value:</source>
        <translation>Valor inválido:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>Coordenada ou distância inválida &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Warning</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Aviso
Atenção
Aviso:</translatorcomment>
        <translation>Aviso</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Expression</source>
        <translation>Expressão</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translatorcomment>--exact match--
--file: SnapCoordinate_pt.ts--
&amp;Coordenadas
Coordenadas
Salta a uma coordenada dada</translatorcomment>
        <translation>Coordenada</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
Linha de Comando</translatorcomment>
        <translation>Comando</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Comando:
Impossível executar o comando: %s</translatorcomment>
        <translation>Comando:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translatorcomment>--exact match--
--file: LibraryBrowser_pt.ts--
Desenho guardado: %1
Documento carregado: %1</translatorcomment>
        <translation>: </translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tamanho do Histórico:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translation>Exiba avisos como caixas de diálogo</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translation>Exiba informações como caixas de diálogo</translation>
    </message>
</context>
</TS>
